@@ -38,7 +38,7 @@ char copyright[] =
 #ifndef lint
 /*static char sccsid[] = "from: @(#)vacation.c	5.19 (Berkeley) 3/23/91";*/
 static char rcsid[] __attribute__ ((unused)) =
-  "$Id: vacation.c 110 2008-07-03 11:42:47Z chrissamuel $";
+  "$Id$";
 #endif /* not lint */
 
 /*
@@ -114,6 +114,7 @@ main (int argc, char **argv)
   char *vacation;
   char *vdomain;
   char *vusername;
+  char tmpusername[ 1024 ];
 
   openlog ("vacation", LOG_PID, LOG_MAIL);
   opterr = iflag = nflag = rflag = 0;
@@ -186,7 +187,8 @@ main (int argc, char **argv)
     }
   else if (!(pw = getpwnam (*argv)))
     {
-      syslog (LOG_ERR, "vacation: no such user %s.\n", *argv);
+      snprintf( tmpusername, 1023, "%s", *argv );
+      syslog (LOG_ERR, "vacation: no such user %s.\n", tmpusername);
       exit (1);
     }
   if (chdir (pw->pw_dir))
@@ -375,6 +377,19 @@ readheaders (void)
 	    !strncasecmp (p, "list", 4) || !strncasecmp (p, "bulk", 4))
 	  exit (0);
 	break;
+      case 'A':		/* "Auto-Submitted:" */
+	cont = 0;
+	if (strncasecmp (buf, "Auto-Submitted", 14) ||
+	    (buf[14] != ':' && buf[14] != ' ' && buf[14] != '\t'))
+	  break;
+	if (!(p = index (buf, ':')))
+	  break;
+	while (*++p && isspace (*p));
+	if (!*p)
+	  break;
+	if (strncasecmp (p, "no", 2))
+	  exit (0);
+	break;
       case 'C':		/* "Cc:" */
 	if (strncasecmp (buf, "Cc:", 3))
 	  break;
@@ -598,33 +613,14 @@ setreply (void)
 void
 sendmessage (char *myname, char *myrealname)
 {
-  register char *p;
   FILE *mfp, *sfp;
   int i;
   int pvect[2];
   char buf[MAXLINE];
   char line[MAXLINE];
 
-  if ((p = index (myrealname, ',')))
-    {				/* realname with , ? */
-      *p = '\0';		/* let string end here */
-    }
-  while ((p = index (myrealname, ' ')))
-    {
-      *p = '_';			/* replace all blanks to underlines */
-    }
-  if (index (myrealname, '(') || index (myrealname, ')'))
-    {
-      *buf = '\"';		/* put " around realnames with () */
-      (void) strlcpy (buf + 1, myrealname, MAXLINE);
-      strlcat (buf, "\"", MAXLINE);
-    }
-  else
-    {				/* this is a normal realname */
-      (void) strlcpy (buf, myrealname, MAXLINE);
-    }
 #ifdef DEBUG
-  snprintf (logline, MAXLINE, "sendmessage: using realname >%s<", buf);	/* Flawfinder: ignore */
+  snprintf (logline, MAXLINE, "sendmessage: using realname >%s<", myrealname);	/* Flawfinder: ignore */
   printd (logline);
 #endif
 
@@ -651,7 +647,7 @@ sendmessage (char *myname, char *myrealname)
       close (pvect[0]);
       close (pvect[1]);
       fclose (mfp);
-      execl (_PATH_SENDMAIL, "sendmail", "-f", myname, "-F", buf, "--", from,
+      execl (_PATH_SENDMAIL, "sendmail", "-f", myname, "-F", myrealname, "--", from,
 	     NULL);
       syslog (LOG_ERR, "vacation: can't exec %s: %s", _PATH_SENDMAIL,
 	      strerror (errno));
@@ -660,6 +656,7 @@ sendmessage (char *myname, char *myrealname)
   close (pvect[0]);
   sfp = fdopen (pvect[1], "w");
   fprintf (sfp, "Precedence: bulk\n");
+  fprintf (sfp, "Auto-Submitted: auto-replied\n" ); /* RFC-3834 */
   fprintf (sfp, "User-Agent: %s http://vacation.sourceforge.net\n", VACVERS);
   fprintf (sfp, "To: %s\n", from);
   while (fgets (buf, sizeof buf, mfp))
@@ -714,7 +711,7 @@ initialize (char *path, char *myname)
 {
   char *editor;
   char ebuf[PATH_MAX];
-  char c;
+  int  c;
   FILE *message;
   FILE *oldmessage;
   FILE *forward;
@@ -737,7 +734,7 @@ initialize (char *path, char *myname)
 	}
       while (((c = fgetc (forward)) != EOF))
 	{
-	  fprintf (oldforward, "%c", c);
+	  fprintf (oldforward, "%c", ( unsigned char ) c);
 	  chmod (OLDFWD, 00600);
 	}
       fclose (oldforward);
@@ -771,7 +768,6 @@ initialize (char *path, char *myname)
 	  fprintf (stderr, "vacation: cannot open %s\n", VMSG);
 	  exit (1);
 	}
-      message = fopen (VMSG, "w");
       fprintf (message, "Subject: away from my mail\n\n");
       fprintf (message, "I will not be reading my mail for a while.\n");
       fprintf (message, "Your mail concerning \"$SUBJECT\"\n");
@@ -786,7 +782,7 @@ initialize (char *path, char *myname)
 	}
       while (((c = fgetc (message)) != EOF))
 	{
-	  fprintf (oldmessage, "%c", c);
+	  fprintf (oldmessage, "%c", ( unsigned char ) c);
 	}
       fclose (oldmessage);
     }
